@@ -19,7 +19,7 @@
 int
 load_db(const char *filename)
 {
-  int ret;
+  int ret = 0;     /* silence gcc 2.7.2.1 */
   int readnew=1;
   Elan_t *elan =NULL;
   char message[300];
