@@ -60,7 +60,7 @@
 * Dependencies:
 *   types.h    - Generally used type definitions.
 *   codes.h    - Completion codes.
-*   atm.h      - ATM specific definitions and types.
+*   lane_atm.h - ATM specific definitions and types.
 *   svc_info.h - SVC Information Block Definitions.
 *
 * Description:
@@ -117,13 +117,13 @@
 *
 *     The connection manager is not specific to any particular ATM Adaptation
 *     Layer (AAL).  An AAL_Data field is passed along with each transmit and
-*     receive packet.  Refer to the definition of AAL_DATA in the "atm.h"
+*     receive packet.  Refer to the definition of AAL_DATA in the "lane_atm.h"
 *     header file.
 *
 */
 #ifndef CM_SAP_H
 #define CM_SAP_H
-#include "atm.h"
+#include "lane_atm.h"
 #include "svc_info.h"
 #include "system.h"
 /*************************************************************************
