@@ -109,6 +109,7 @@ extern const char *state_name[],*cs_name[],*as_name[];
 extern unsigned char q_buffer[];
 
 #define DEFAULT_TRACE_SIZE 20
+#define DEFAULT_DUMP_DIR "/var/tmp"
 
 extern int pretty;
 extern const char *dump_dir;
@@ -163,7 +164,8 @@ int get_itf(SIG_ENTITY *sig,int *vpci);
 void init_addr(SIG_ENTITY *sig);
 
 void add_route(SIG_ENTITY *sig,struct sockaddr_atmsvc *addr,int len);
-SIG_ENTITY *route_call(struct sockaddr_atmsvc *addr);
+SIG_ENTITY *route_remote(struct sockaddr_atmsvc *addr);
+SIG_ENTITY *route_local(struct sockaddr_atmsvc *addr);
 
 SIG_ENTITY *get_sig_entity(int itf);
 
